@@ -3,7 +3,7 @@ from nonebot.plugin import on_command
 from nonebot.adapters.onebot.v11 import PrivateMessageEvent, GroupMessageEvent, Message, MessageEvent
 from nonebot.typing import T_State
 from nonebot.params import ArgStr, CommandArg
-from nonebot_plugin_apscheduler import scheduler
+
 from nonebot import require
 from libxduauth import EhallSession, SportsSession, XKSession
 from builtins import ConnectionError
@@ -11,9 +11,14 @@ from pathlib import Path
 import asyncio
 from datetime import datetime
 import os
-from .model import check, corn_check, get_sport_record, get_timetable, get_whole_day_course, get_next_course, get_question, des_encrypt, des_descrypt
+from .model import check, cron_check, get_sport_record, get_timetable, get_whole_day_course, get_next_course, get_question, des_encrypt, des_descrypt
 from .config import Config
 
+# 启动定时器---------------------------------------------------------------
+
+require("nonebot_plugin_apscheduler")
+
+from nonebot_plugin_apscheduler import scheduler
 
 # 配置初始项---------------------------------------------------------------
 
@@ -69,14 +74,15 @@ XDU_SUPPORT_PATH = os.path.join(xdu_support_path, "user_data")
 if not os.path.exists(XDU_SUPPORT_PATH):
     os.makedirs(XDU_SUPPORT_PATH)
 
+for name in MODLE.values():
+    if not os.path.exists(os.path.join(XDU_SUPPORT_PATH, f"{name}.txt")):
+        f = open(os.path.join(XDU_SUPPORT_PATH, f"{name}.txt"), 'w')
+        f.close()
+
 STATE_OK = True
 STATE_ERROR = False
 
 
-# 启动定时器---------------------------------------------------------------
-
-require("nonebot_plugin_apscheduler")
-
 # 注册匹配器----------------------------------------------------------------
 
 add_sub = on_command(
@@ -127,6 +133,8 @@ async def handle(event: PrivateMessageEvent, state: T_State, args: Message = Com
 
 @add_sub.got("model", prompt="请输入想要订阅的功能名称")
 async def got_model(event: PrivateMessageEvent, state: T_State, model_: str = ArgStr("model")):
+    if model_ in ["取消", "算了"]:
+        await add_sub.finish("已取消本次操作")
     model = MODLE.get(model_, None)
     state["model"] = model_
     await asyncio.sleep(1)
@@ -148,6 +156,7 @@ async def got_model(event: PrivateMessageEvent, state: T_State, model_: str = Ar
                 res += "==========================\n"
                 for info in infos:
                     res += info + '\n'
+                res += "虽然对密码进行了加密处理，但是很遗憾，所有加密都是可逆的，如果不了解bot的主人请谨慎使用插件，谨慎填写密码。可以回复'算了'或者'取消'来取消本次操作，或者在使用完功能后及时取消订阅以免造成损失"
                 await add_sub.send(res)
         else:
             await add_sub.finish("读取信息出错了，请及时联系管理员")
@@ -157,6 +166,8 @@ async def got_model(event: PrivateMessageEvent, state: T_State, model_: str = Ar
 
 @add_sub.got("info", prompt="请以空格对不同信息进行分割，并且不要改变顺序,例如'123456789 abcdefghi'")
 async def got_info(event: PrivateMessageEvent, state: T_State, info: str = ArgStr("info")):
+    if info in ["取消", "算了"]:
+        await add_sub.finish("已取消本次操作")
     flag = 0
     await asyncio.sleep(1)
     path = state["path"]
@@ -186,7 +197,8 @@ async def got_info(event: PrivateMessageEvent, state: T_State, info: str = ArgSt
         if infos[0] == "随便输入一些吧，反正也不需要补充信息~":
             users.append([user_id, "0", "0"])
         else:
-            users.append([user_id] + [info[0], des_encrypt(info[1], DES_KEY).decode()])
+            users.append([user_id] +
+                         [info[0], des_encrypt(info[1], DES_KEY).decode()])
         if write_data(path=path, data=users):
             await add_sub.finish(f"成功订阅功能{state['model']}")
         else:
@@ -218,6 +230,9 @@ async def handle(state: T_State, args: Message = CommandArg()):
 
 @cancel_sub.got("model", prompt="请输入想要取消订阅的功能名称")
 async def got_model(event: MessageEvent, model_: str = ArgStr("model")):
+    if model_ in ["取消", "算了"]:
+        await cancel_sub.finish("已取消本次操作")
+
     model = MODLE.get(model_, None)
     await asyncio.sleep(1)
     if model:
@@ -251,7 +266,8 @@ async def _(event: MessageEvent):
     if flag:
         if user_id in users_id:
             username = users[users_id.index(user_id)][1]
-            password = des_descrypt(users[users_id.index(user_id)][2], DES_KEY).decode()
+            password = des_descrypt(
+                users[users_id.index(user_id)][2], DES_KEY).decode()
             message = check(username, password)
             await chenwuwanjian.finish(message=f'[{datetime.now().strftime("%d/%m/%Y %H:%M:%S")}] {message}')
         else:
@@ -279,7 +295,7 @@ async def run_every_7_hour():
 
 
 # 定时每10分钟查一次
-@scheduler.scheduled_job("corn", minute="*/10", hour="7-22", month="2-7,9-12")
+@scheduler.scheduled_job("cron", minute="*/10", hour="7-22", month="2-7,9-12")
 async def run_every_10_minutes():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Sports.txt")
@@ -287,7 +303,7 @@ async def run_every_10_minutes():
     if flag:
         for user in users:
             ses = SportsSession(user[1], user[2])
-            flag, res = corn_check(ses, user[1])
+            flag, res = cron_check(ses, user[1])
             if not flag:
                 await asyncio.sleep(1)
                 await bot.send_private_msg(user_id=int(user[0]), message=res)
@@ -302,7 +318,8 @@ async def _(event: MessageEvent):
     user_id = str(event.user_id)
     if user_id in users_id:
         username = users[users_id.index(user_id)][1]
-        password = des_descrypt(users[users_id.index(user_id)][2], DES_KEY).decode()
+        password = des_descrypt(
+            users[users_id.index(user_id)][2], DES_KEY).decode()
         ses = SportsSession(username, password)
         flag, res = get_sport_record(ses, username)
         await sport_punch.send(res)
@@ -333,7 +350,8 @@ async def _(event: MessageEvent):
     user_id = str(event.user_id)
     if user_id in users_id:
         username = users[users_id.index(user_id)][1]
-        password = des_descrypt(users[users_id.index(user_id)][2], DES_KEY).decode()
+        password = des_descrypt(
+            users[users_id.index(user_id)][2], DES_KEY).decode()
 
         ses = EhallSession(username, password)
         ses.use_app(4770397878132218)
@@ -352,7 +370,8 @@ async def _(event: MessageEvent):
     message = ""
     if user_id in users_id:
         username = users[users_id.index(user_id)][1]
-        password = des_descrypt(users[users_id.index(user_id)][2], DES_KEY).decode()
+        password = des_descrypt(
+            users[users_id.index(user_id)][2], DES_KEY).decode()
         if not os.path.exists(
             os.path.join(
                 XDU_SUPPORT_PATH,
@@ -367,7 +386,7 @@ async def _(event: MessageEvent):
         await timetable.finish("请先订阅课表提醒功能，再进行查询")
 
 
-@scheduler.scheduled_job("corn", hour="8", month="2-7,9-12")
+@scheduler.scheduled_job("cron", hour="8", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -386,7 +405,7 @@ async def run_at_8():
                                    message='课表提醒读取数据失败，快维修')
 
 
-@scheduler.scheduled_job("corn", minute="55", hour="9", month="2-7,9-12")
+@scheduler.scheduled_job("cron", minute="55", hour="9", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -405,7 +424,7 @@ async def run_at_8():
                                    message='课表提醒读取数据失败，快维修')
 
 
-@scheduler.scheduled_job("corn", minute="30", hour="13", month="2-7,9-12")
+@scheduler.scheduled_job("cron", minute="30", hour="13", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -424,7 +443,7 @@ async def run_at_8():
                                    message='课表提醒读取数据失败，快维修')
 
 
-@scheduler.scheduled_job("corn", minute="25", hour="15", month="2-7,9-12")
+@scheduler.scheduled_job("cron", minute="25", hour="15", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -443,7 +462,7 @@ async def run_at_8():
                                    message='课表提醒读取数据失败，快维修')
 
 
-@scheduler.scheduled_job("corn", minute="30", hour="18", month="2-7,9-12")
+@scheduler.scheduled_job("cron", minute="30", hour="18", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -462,7 +481,7 @@ async def run_at_8():
                                    message='课表提醒读取数据失败，快维修')
 
 
-@scheduler.scheduled_job("corn", hour="22", month="2-7,9-12")
+@scheduler.scheduled_job("cron", hour="22", month="2-7,9-12")
 async def run_at_8():
     bot = nonebot.get_bot()
     path = Path(XDU_SUPPORT_PATH, "Ehall.txt")
@@ -567,7 +586,10 @@ def read_data(path: Path) -> (bool, list):
     try:
         with open(path, 'r', encoding='utf-8') as f:
             data = f.readlines()
-        infos = [x.split() for x in data]
+        if data:
+            infos = [x.split() for x in data]
+        else:
+            infos = []
 
         return STATE_OK, infos
     except BaseException as e:
