@@ -161,6 +161,6 @@ questions_multi:dict[Union[str, Any], Union[str, Any]] = {
     "绝对剩余价值生产和相对剩余价值生产的共同点是()\n[A]都体现着资本家对工人的剥削关系\n[B]都延长了剩余劳动时间，绝对减少剩余价值量\n[C]都提高了剩余价值率\n[D]都缩短了必要劳动时间":"AC",
     "属于共产主义社会的基本特征是()\n[A]物质财富极大丰富，消费资料按需分配\n[B] 社会关系高度和谐，人们精神境界极大提高\n[C] 实现每个人自由而全面的发展，人类从必然王国向自由王国飞跃\n[D] 实现社会的绝对公平":"ABC",
     "下列属于社会基本矛盾的是()\n[A]生产力和生产关系的矛盾\n[B]经济基础和上层建筑的矛盾\n[C]同一性与斗争性的矛盾\n[D]社会存在与社会统一的矛盾":"AB",
-    "资本主义产生的途径有()\n[A]从小商品经济分化出来\n[B]从商人和高利贷者转化而来\n[C]从无产阶级中转化而来\n[C]从奴隶主阶级转化而来":"AB",
+    "资本主义产生的途径有()\n[A]从小商品经济分化出来\n[B]从商人和高利贷者转化而来\n[C]从无产阶级中转化而来\n[D]从奴隶主阶级转化而来":"AB",
 
 }
